@@ -798,7 +798,8 @@ down (this *won't* always work)."
 
 (defun browse-url-url-at-point ()
   (let ((url (thing-at-point 'url)))
-    (set-text-properties 0 (length url) nil url)
+    (when (featurep 'xemacs)
+      (set-text-properties 0 (length url) nil url))
     url))
 
 ;; Having this as a separate function called by the browser-specific
@@ -987,7 +988,9 @@ to use."
 
 (defun browse-url-default-windows-browser (url &optional new-window)
   (interactive (browse-url-interactive-arg "URL: "))
-  (w32-shell-execute "open" url))
+  (if (featurep 'xemacs)
+      (mswindows-shell-execute "open" url)
+    (w32-shell-execute "open" url)))
 
 ;; --- Netscape ---
 
@@ -1037,7 +1040,7 @@ used instead of `browse-url-new-window-p'."
 			 browse-url-netscape-program
 			 (append
 			  browse-url-netscape-arguments
-			  (if (eq window-system 'w32)
+			  (if (eq (console-type) 'mswindows)
 			      (list url)
 			    (append
 			     (if new-window '("-noraise"))
